==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QPictureIOHandler_shell.cpp <==
#include "QPictureIOHandler_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_picture_io_handler(void *ptr,bool) { delete reinterpret_cast<QPictureIOHandler_shell*>(ptr); }


QPictureIOHandler_shell::QPictureIOHandler_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPictureIOHandler_shell::QPictureIOHandler_shell()")
    QPictureIOHandler_shell::__shell()->constructed(typeid(picture_io_handler));
}

// emitting (writeShellDestructor)
QPictureIOHandler_shell::~QPictureIOHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPictureIOHandler_shell::~QPictureIOHandler_shell()", QPictureIOHandler_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QPictureIOHandler_shell::__shell()->destructed(typeid(picture_io_handler));
}

// construct QPictureIOHandler_shell
void __qt_construct_picture_io_handler_0(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct picture_io_handler")
    new (__qtjambi_ptr) QPictureIOHandler_shell();
}
// destruct QPictureIOHandler_shell
void __qt_destruct_picture_io_handler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct picture_io_handler")
    reinterpret_cast<QPictureIOHandler_shell*>(ptr)->~QPictureIOHandler_shell();
}

void QPictureIOHandler_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPictureIOHandler_shell*>(ptr)->QPictureIOHandler_shell::__shell()->tryDeleteShell(typeid(picture_io_handler));
}

QtJambiShell* QPictureIOHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPictureIOHandler_shell) ); }

QPictureIOHandler_shell::Functor::Functor(QPictureIOHandler_shell& functional) : FunctorBase(typeid(picture_io_handler), functional) {}

QPictureIOHandler_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QPictureIOHandler_shell::Functor::~Functor() {}

void QPictureIOHandler_shell::Functor::operator()(QPictureIO* arg__1)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    QTJAMBI_INVALIDATE_AFTER_USE(env, __java_arg__1);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "picture_io_handler");
            } QTJAMBI_TRY_END
        }
    }
}

void QPictureIOHandler_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QPictureIOHandler_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<picture_io_handler*>(result) = qtjambi_function_pointer<14,void(QPictureIO*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QPictureIOHandler_shell::resolveFunctional(JNIEnv * env, const picture_io_handler* function)
{
    if(function && reverseFunctionGetter){
        if(const QPictureIOHandler_shell::Functor* functor = reverseFunctionGetter(*function)){
            return functor->getJavaObjectLocalRef(env);
        }
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPictureIOHandler_00024Impl_00024ConcreteWrapper_accept_1native__J)
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPictureIOHandler(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        picture_io_handler* function = QtJambiAPI::convertJavaInterfaceToNative<picture_io_handler>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QPictureIO* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QPictureIO>(arg__1);
        (*function)(__qt_arg__1);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPictureIOHandler_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPictureIOHandler_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_picture_io_handler_0, sizeof(QPictureIOHandler_shell), typeid(picture_io_handler), &deleter_picture_io_handler);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QPictureIOHandler_shell::Functor*(picture_io_handler)> QPictureIOHandler_shell::reverseFunctionGetter = std::function<const QPictureIOHandler_shell::Functor*(picture_io_handler)>();

void initialize_meta_info_picture_io_handler(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<picture_io_handler, QPictureIOHandler_shell>("picture_io_handler", "io/qt/gui/QPictureIOHandler",
                              &deleter_picture_io_handler,
                              &__qt_destruct_picture_io_handler,
                              {ConstructorInfo(&__qt_construct_picture_io_handler_0, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/gui/QPictureIO;)V", FunctionInfo::Abstract)});
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPictureIOHandler_shell.cpp <==
#include "QPictureIOHandler_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_picture_io_handler(void *ptr,bool) { delete reinterpret_cast<QPictureIOHandler_shell*>(ptr); }


QPictureIOHandler_shell::QPictureIOHandler_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPictureIOHandler_shell::QPictureIOHandler_shell()")
    QPictureIOHandler_shell::__shell()->constructed(typeid(picture_io_handler));
}

// emitting (writeShellDestructor)
QPictureIOHandler_shell::~QPictureIOHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPictureIOHandler_shell::~QPictureIOHandler_shell()", QPictureIOHandler_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QPictureIOHandler_shell::__shell()->destructed(typeid(picture_io_handler));
}

// construct QPictureIOHandler_shell
void __qt_construct_picture_io_handler(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct picture_io_handler")
    new (__qtjambi_ptr) QPictureIOHandler_shell();
}
// destruct QPictureIOHandler_shell
void __qt_destruct_picture_io_handler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct picture_io_handler")
    reinterpret_cast<QPictureIOHandler_shell*>(ptr)->~QPictureIOHandler_shell();
}

void QPictureIOHandler_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPictureIOHandler_shell*>(ptr)->QPictureIOHandler_shell::__shell()->tryDeleteShell(typeid(picture_io_handler));
}

QtJambiShell* QPictureIOHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPictureIOHandler_shell) ); }

QPictureIOHandler_shell::Functor::Functor(QPictureIOHandler_shell& functional) : FunctorBase(typeid(picture_io_handler), functional) {}

QPictureIOHandler_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QPictureIOHandler_shell::Functor::~Functor() {}

void QPictureIOHandler_shell::Functor::operator()(QPictureIO* arg__1)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    QTJAMBI_INVALIDATE_AFTER_USE(env, __java_arg__1);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                __qj_exnhandler.handle(env, exn, "picture_io_handler");
            } QTJAMBI_TRY_END
        }
    }
}

void QPictureIOHandler_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QPictureIOHandler_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<picture_io_handler*>(result) = qtjambi_function_pointer<14,void(QPictureIO*)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QPictureIOHandler_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const picture_io_handler& function = *reinterpret_cast<const picture_io_handler*>(functionPtr);
        if(const QPictureIOHandler_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPictureIOHandler_00024Impl_00024ConcreteWrapper_accept_1native__J)
(JNIEnv *__jni_env, jobject __this, QtJambiNativeID arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPictureIOHandler(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        picture_io_handler* function = QtJambiAPI::convertJavaInterfaceToNative<picture_io_handler>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        QPictureIO* __qt_arg__1 = QtJambiAPI::objectFromNativeId<QPictureIO>(arg__1);
        (*function)(__qt_arg__1);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QPictureIOHandler_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPictureIOHandler_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_picture_io_handler, sizeof(QPictureIOHandler_shell), typeid(picture_io_handler), &deleter_picture_io_handler);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QPictureIOHandler_shell::Functor*(picture_io_handler)> QPictureIOHandler_shell::reverseFunctionGetter = std::function<const QPictureIOHandler_shell::Functor*(picture_io_handler)>();

void initialize_meta_info_picture_io_handler(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<picture_io_handler, QPictureIOHandler_shell>("picture_io_handler", "io/qt/gui/QPictureIOHandler",
                              &deleter_picture_io_handler,
                              &__qt_destruct_picture_io_handler,
                              {ConstructorInfo(&__qt_construct_picture_io_handler, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/gui/QPictureIO;)V", FunctionInfo::Abstract)});
}
